@@ -1,3 +1,5 @@
+from __future__ import unicode_literals
+
 from django.db import models
 
 
@@ -8,3 +10,6 @@ class Dependency(models.Model):
 
     class Meta:
         unique_together = ("source", "depends_on")
+
+    def __unicode__(self):
+        return "{0} depends on {1}".format(self.source, self.depends_on)
