@@ -196,12 +196,12 @@ def test_compile_lazy(monkeypatch):
     # noinspection PyUnresolvedReferences
     assert compiler.compile.calls == []
 
-    assert encoding.force_text(lazy_compiled) == "dummy.coffee"
+    assert encoding.force_str(lazy_compiled) == "dummy.coffee"
 
     # noinspection PyUnresolvedReferences
     assert compiler.compile.calls == [pretend.call("dummy.coffee")]
 
-    assert compiler.compile(encoding.force_text("foo")).startswith(encoding.force_text("")) is True
+    assert compiler.compile(encoding.force_str("foo")).startswith(encoding.force_str("")) is True
     assert compiler.compile(encoding.force_bytes("foo")).startswith(encoding.force_bytes("")) is True
 
 
