@@ -75,6 +75,9 @@ def test_sourcemap(compiler_module, monkeypatch, tmpdir):
     assert sourcemap["sources"] == ["test.scss"]
     assert sourcemap["file"] == "test.css"
 
+    with open(full_output_path) as compiled_file:
+        assert "/*# sourceMappingURL=test.css.map */" in {line.strip() for line in compiled_file.readlines()}
+
 
 @pytest.mark.parametrize("compiler_module", (libsass, scss))
 def test_compile_source(compiler_module):
